#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parallel
version:              3.2.2.0
visibility:           public
id:                   parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
key:                  parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Parallel programming library
description:
    This package provides a library for parallel programming.

    For documentation start from the "Control.Parallel.Strategies"
    module below.

    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.

    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.

category:             Control, Parallelism
abi:                  981f4c95461f5e6990de86d114495016
exposed:              True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq

import-dirs:          /usr/lib/ghc-9.6.6/site-local/parallel-3.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/parallel-3.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parallel
hs-libraries:         HSparallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0

haddock-interfaces:   /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html:         /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

